Stan Math Library: stan/math/version.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Macros | Variables
version.hpp File Reference
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Macros
#define | STAN_STRING_EXPAND(s) #s
#define | STAN_STRING(s) STAN_STRING_EXPAND(s)
#define | STAN_MATH_MAJOR 2
#define | STAN_MATH_MINOR 10
#define | STAN_MATH_PATCH 0

## Variables
const std::string | stan::math::MAJOR_VERSION = STAN_STRING(STAN_MATH_MAJOR)
| Major version number for Stan math library. More...
const std::string | stan::math::MINOR_VERSION = STAN_STRING(STAN_MATH_MINOR)
| Minor version number for Stan math library. More...
const std::string | stan::math::PATCH_VERSION = STAN_STRING(STAN_MATH_PATCH)
| Patch version for Stan math library. More...

## Macro Definition Documentation

#define STAN_MATH_MAJOR 2

Definition at line 14 of file version.hpp.

#define STAN_MATH_MINOR 10

Definition at line 15 of file version.hpp.

#define STAN_MATH_PATCH 0

Definition at line 16 of file version.hpp.

#define STAN_STRING | ( |  | s | ) | STAN_STRING_EXPAND(s)

Definition at line 11 of file version.hpp.

#define STAN_STRING_EXPAND | ( |  | s | ) | #s

Definition at line 7 of file version.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.